==> EnrichDO_0.99.2.tar.gz: EnrichDO/inst/scripts/EnrichDO_exampleTest.R <==
# sample session to exemplify the use of EnrichDO

library(EnrichDO)

EnrichDO_example <- function(path = NULL) {
  if (is.null(path)) {
    dir(system.file("extdata", package = "EnrichDO"))
  } else {
    system.file("extdata", path, package = "EnrichDO", mustWork = TRUE)
  }
}
#View all the enrichment input data involved in the literature under the inst/extdata folder
EnrichDO_example()

#Take the curated genes for Alzheimer's as input
Alzheimer<-read.csv(EnrichDO_example("Alzheimer_curated.csv"),header = F)
Alzheimer_gene<-Alzheimer$V1

#Enrichment Analysis
Alzheimer_EnrichDO<-doEnrich(interestGenes = Alzheimer_gene,
                     test         = "hypergeomTest",
                     method       = "BH",
                     m            = 1,
                     maxGsize     = 5000,
                     minGsize     = 5,
                     traditional  = FALSE,
                     delta        = 0.01,
                     result_do    = NULL,
                     penalize     = T)

#Enrichment result visualization
writeDoTerms(doterms,file = file.path(system.file("examples", package = "EnrichDO"),"doterms.txt"))
writeResult(enrich,file = file.path(system.file("examples", package = "EnrichDO"),"result.txt"),Q=1,P=1)

pdf(file.path(system.file("examples", package = "EnrichDO"),"BarGraph.pdf"))
drawBarGraph(enrich,n=10,delta = 0.05)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"PointGraph.pdf"))
drawPointGraph(enrich,n=10,delta = 0.05)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"TreeGraph.pdf"))
drawGraphViz(enrich, n=10, numview=FALSE, pview=FALSE,labelfontsize = 17)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"HeatmapGraph.pdf"))
drawHeatmap(interestGenes=Alzheimer_gene,
            enrich = enrich,
            gene_n = 10,
            fontsize_row = 8,
            readable=T)
dev.off()

==> EnrichDO_0.99.11.tar.gz: EnrichDO/inst/scripts/EnrichDO_exampleTest.R <==
# sample session to exemplify the use of EnrichDO

library(EnrichDO)

EnrichDO_example <- function(path = NULL) {
  if (is.null(path)) {
    dir(system.file("extdata", package = "EnrichDO"))
  } else {
    system.file("extdata", path, package = "EnrichDO", mustWork = TRUE)
  }
}
#View all the enrichment input data involved in the literature under the inst/extdata folder
EnrichDO_example()

#Take the curated genes for Alzheimer's as input
Alzheimer<-read.csv(EnrichDO_example("Alzheimer_curated.csv"),header = F)
Alzheimer_gene<-Alzheimer$V1

#Enrichment Analysis
Alzheimer_EnrichDO<-doEnrich(interestGenes = Alzheimer_gene,
                     test         = "hypergeomTest",
                     method       = "BH",
                     m            = 1,
                     maxGsize     = 5000,
                     minGsize     = 5,
                     traditional  = FALSE,
                     delta        = 0.01,
                     penalize     = T)
enrich<-EnrichTab(object=Alzheimer_EnrichDO,all = TRUE)
#Enrichment result visualization
writeDoTerms(doterms,file = file.path(system.file("examples", package = "EnrichDO"),"doterms.txt"))
writeResult(enrich,file = file.path(system.file("examples", package = "EnrichDO"),"result.txt"),Q=1,P=1)

pdf(file.path(system.file("examples", package = "EnrichDO"),"BarGraph.pdf"))
drawBarGraph(enrich=enrich,n=10,delta = 0.05)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"PointGraph.pdf"))
drawPointGraph(enrich=enrich,n=10,delta = 0.05)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"TreeGraph.pdf"))
drawGraphViz(EnrichResult=Alzheimer_EnrichDO, n=10, numview = FALSE, pview = FALSE,labelfontsize = 17)
dev.off()

pdf(file.path(system.file("examples", package = "EnrichDO"),"HeatmapGraph.pdf"))
drawHeatmap(interestGenes=Alzheimer_gene,
            enrich = enrich,
            gene_n = 10,
            fontsize_row = 8,
            readable=T)
dev.off()
